@@ -22,13 +22,13 @@ import socket
 
 LOG = logging.getLogger(__name__)
 
-from calico import datamodel_v1
-from calico.etcdutils import EtcdWatcher
 from networking_calico.agent.dhcp_agent import CalicoDhcpAgent
 from networking_calico.agent.dhcp_agent import FakePlugin
 from networking_calico.agent.dhcp_agent import get_etcd_connection_settings
 from networking_calico.agent.linux.dhcp import DnsmasqRouted
 from networking_calico.common import config as calico_config
+from networking_calico import datamodel_v1
+from networking_calico.etcdutils import EtcdWatcher
 from neutron.agent.dhcp_agent import register_options
 from neutron.agent.linux import dhcp
 from neutron.common import constants
